@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -164,6 +164,30 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDBInstanceParamTpl(self, request):
+        """本接口(CreateDBInstanceParamTpl)用于创建云数据库MongoDB实例的参数模板
+        **说明：CreateDBInstanceParamTpl API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for CreateDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.CreateDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.CreateDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAccountUser(self, request):
         """本接口（DeleteAccountUser）用于删除实例的自定义账号。
 
@@ -211,7 +235,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeAsyncRequestInfo(self, request):
-        """查询异步任务状态接口
+        """本接口（DescribeAsyncRequestInfo）用于查询异步任务状态接口。
 
         :param request: Request instance for DescribeAsyncRequestInfo.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeAsyncRequestInfoRequest`
@@ -303,7 +327,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeCurrentOp(self, request):
-        """本接口(DescribeCurrentOp)用于查询MongoDB云数据库实例的当前正在执行的操作。
+        """本接口（DescribeCurrentOp）用于查询云数据库实例的当前正在执行的操作。
 
         :param request: Request instance for DescribeCurrentOp.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeCurrentOpRequest`
@@ -371,6 +395,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDBInstanceNamespace(self, request):
+        """本接口（DescribeDBInstanceNamespace）用于查询数据库的表信息。
+
+        :param request: Request instance for DescribeDBInstanceNamespace.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceNamespaceRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceNamespaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBInstanceNamespace", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDBInstanceNamespaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDBInstanceNodeProperty(self, request):
         """本接口用于查询节点的属性，包括节点所在可用区、节点名称、地址、角色、状态、主从延迟、优先级、投票权、标签等属性。
 
@@ -394,6 +441,77 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDBInstanceParamTpl(self, request):
+        """本接口(DescribeDBInstanceParamTpl )用于查询当前账号下所有MongoDB数据库参数模板
+        **说明：DescribeDBInstanceParamTpl  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for DescribeDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeDBInstanceParamTplDetail(self, request):
+        """本接口(DescribeDBInstanceParamTplDetail )用于查询MongoDB云数据库实例的参数模板详情。
+        **说明：DescribeDBInstanceParamTplDetail  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for DescribeDBInstanceParamTplDetail.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplDetailRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBInstanceParamTplDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDBInstanceParamTplDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeDBInstanceURL(self, request):
+        """本接口（DescribeDBInstanceURL）用于获取指定实例的 URI 形式的连接串访问地址示例。
+
+        :param request: Request instance for DescribeDBInstanceURL.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceURLRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceURLResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBInstanceURL", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDBInstanceURLResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDBInstances(self, request):
         """本接口（DescribeDBInstances）用于查询云数据库实例列表，支持通过项目ID、实例ID、实例状态等过滤条件来筛选主实例、灾备实例和只读实例信息列表。
 
@@ -417,6 +535,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDetailedSlowLogs(self, request):
+        """查询实例慢日志详情
+
+        :param request: Request instance for DescribeDetailedSlowLogs.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDetailedSlowLogsRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDetailedSlowLogsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDetailedSlowLogs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDetailedSlowLogsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstanceParams(self, request):
         """本接口（DescribeInstanceParams）用于查询当前实例可修改的参数列表。
 
@@ -555,8 +696,32 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DropDBInstanceParamTpl(self, request):
+        """本接口(DropDBInstanceParamTpl )用于删除云数据库MongoDB实例的参数模板
+        **说明：DropDBInstanceParamTpl  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for DropDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DropDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DropDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DropDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DropDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def EnableTransparentDataEncryption(self, request):
-        """本接口(EnableTransparentDataEncryption)用于开启云数据库 MongoDB 的透明加密能力。
+        """本接口（EnableTransparentDataEncryption）用于开启云数据库 MongoDB 的透明加密能力。
 
         :param request: Request instance for EnableTransparentDataEncryption.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.EnableTransparentDataEncryptionRequest`
@@ -763,6 +928,30 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDBInstanceParamTpl(self, request):
+        """本接口(ModifyDBInstanceParamTpl )用于修改MongoDB云数据库实例的参数模板。
+        **说明：ModifyDBInstanceParamTpl  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for ModifyDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.ModifyDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.ModifyDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDBInstanceSecurityGroup(self, request):
         """本接口（ModifyDBInstanceSecurityGroup）用于修改实例绑定的安全组
 
@@ -924,6 +1113,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestartNodes(self, request):
+        """本接口用于重启数据库节点。
+
+        :param request: Request instance for RestartNodes.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.RestartNodesRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.RestartNodesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestartNodes", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestartNodesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SetAccountUserPrivilege(self, request):
         """本接口（SetAccountUserPrivilege）用于设置实例的账号权限。
 
